Struct DragOffer
pub struct DragOffer {
pub serial: u32,
pub surface: WlSurface,
pub x: f64,
pub y: f64,
pub time: Option<u32>,
pub source_actions: DndAction,
pub selected_action: DndAction,
pub dropped: bool,
pub left: bool,
/* private fields */
}wayland and Linux only.Fields
serial: u32the serial for this data offer’s enter event
surface: WlSurfacethe surface that this DnD is active on
x: f64the x position on the surface
y: f64the y position on this surface
time: Option<u32>the timestamp a motion event was received in millisecond granularity
source_actions: DndActionthe advertised drag actions
selected_action: DndActionthe compositor selected drag action
dropped: boolwhether or not the drag has been dropped
left: boolwhether or not the drag has left
Implementations
impl DragOffer
impl DragOffer
pub fn finish(&self)
pub fn with_mime_types<T, F>(&self, callback: F) -> T
pub fn with_mime_types<T, F>(&self, callback: F) -> T
Inspect the mime types available on the given offer.
pub fn set_actions(&self, actions: DndAction, preferred_action: DndAction)
pub fn set_actions(&self, actions: DndAction, preferred_action: DndAction)
Set the accepted and preferred drag and drop actions. This request determines the final result of the drag-and-drop operation. If the end result is that no action is accepted, the drag source will receive wl_data_source.cancelled.
pub fn receive(&self, mime_type: String) -> Result<ReadPipe, Error>
pub fn receive(&self, mime_type: String) -> Result<ReadPipe, Error>
Receive data with the given mime type. This request may happen multiple times for different mime types, both before and after wl_data_device.drop. Drag-and-drop destination clients may preemptively fetch data or examine it more closely to determine acceptance.
pub fn accept_mime_type(&self, serial: u32, mime_type: Option<String>)
pub fn accept_mime_type(&self, serial: u32, mime_type: Option<String>)
Accept the given mime type, or None to reject the offer. In version 2, this request is used for feedback, but doesn’t affect the final result of the drag-and-drop operation. In version 3, this request determines the final result of the drag-and-drop operation.
pub fn destroy(&self)
pub fn destroy(&self)
Destroy the data offer.
pub fn inner(&self) -> &WlDataOffer
pub fn inner(&self) -> &WlDataOffer
Retrieve a reference to the inner wl_data_offer.